abctools
========

.. automodule:: abjad.tools.abctools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.abctools.ContextManager.ContextManager
      ~abjad.tools.abctools.Parser.Parser

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.abctools.AbjadObject.AbjadObject
